@@ -7,7 +7,8 @@ Collection of wrappers for different kind of Objects to be launched by workers.
 
 
 from .func import FuncWrapper
-from .di import TaskWrapper
 from .base import QueueWrapper
+from .di_task import TaskWrapper
 
-__all__ = [ 'FuncWrapper', 'TaskWrapper', 'QueueWrapper' ]
+
+__all__ = ('QueueWrapper', 'FuncWrapper', 'TaskWrapper', )
